/*
 * Copyright (C) 2005-2019 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "otbGlError.h"

#include <sstream>


// This
namespace otb
{

namespace gl
{

Error
::Error( GLenum code ) :
  std::runtime_error(
    [ code ]()
    {
      std::ostringstream oss;

      oss << "OpenGL error #" << code << ": '" << gluErrorString( code ) << "'";

      return oss.str();
    }()
  )
{
}


} // End namespace 'gl'.


} // End namespace 'otb'.
